flutter_resilience library
Classes
- Backoff
- Helper class to calculate delays based on RetryStrategy.
- CircuitBreaker
- Implements the Circuit Breaker pattern to prevent cascading failures.
- ExecutionPipeline
- A class that orchestrates the execution of a task through multiple resilience policies.
- ResilienceLogger
- Simple logger hook for resilience events.
- ResilienceMetrics
- Simple metrics container for resilience events.
- ResiliencePolicy
- A composite policy that combines multiple resilience strategies.
- ResilientClient
- A primary entry point for developers to execute resilient operations.
- RetryPolicy
- Defines a policy for retrying failed operations.
- TimeoutPolicy
- A policy that applies a timeout to an asynchronous operation.
Enums
- CircuitState
- States of a CircuitBreaker.
- RetryStrategy
- Strategies for calculating the delay between retry attempts.
Exceptions / Errors
- CircuitBreakerOpenException
- Exception thrown when the circuit is open.